/* SPDX-License-Identifier: (GPL-2.0-only OR BSD-2-Clause) */
/*
 * Copyright (c) Qualcomm Technologies, Inc. and/or its subsidiaries.
 */

#ifndef _DT_BINDINGS_CLK_QCOM_GX_CLKCTL_KAANAPALI_H
#define _DT_BINDINGS_CLK_QCOM_GX_CLKCTL_KAANAPALI_H

/* GX_CLKCTL power domains */
#define GX_CLKCTL_GX_GDSC				0
#define GX_CLKCTL_GX_SLICE_GDSC				1

#endif
