/* SPDX-License-Identifier: GPL-2.0 */
/*
 * This header provides macros for AT91 USART DT bindings.
 *
 * Copyright (C) 2018 Microchip Technology
 *
 * Author: Radu Pirea <radu.pirea@microchip.com>
 *
 */

#ifndef __DT_BINDINGS_AT91_USART_H__
#define __DT_BINDINGS_AT91_USART_H__

#define AT91_USART_MODE_SERIAL	0
#define AT91_USART_MODE_SPI	1

#endif /* __DT_BINDINGS_AT91_USART_H__ */
