/* SPDX-License-Identifier: GPL-2.0 */

#ifndef _LINUX_FPU_H
#define _LINUX_FPU_H

#ifdef _LINUX_FPU_COMPILATION_UNIT
#error FP code must be compiled separately. See Documentation/core-api/floating-point.rst.
#endif

#include <asm/fpu.h>

#endif
