/* SPDX-License-Identifier: (GPL-2.0-only OR BSD-2-Clause) */

#ifndef _DT_BINDINGS_RESET_MEDIATEK_MT6735_WDT_H_
#define _DT_BINDINGS_RESET_MEDIATEK_MT6735_WDT_H_

#define MT6735_TOPRGU_MM_RST		1
#define MT6735_TOPRGU_MFG_RST		2
#define MT6735_TOPRGU_VENC_RST		3
#define MT6735_TOPRGU_VDEC_RST		4
#define MT6735_TOPRGU_IMG_RST		5
#define MT6735_TOPRGU_MD_RST		7
#define MT6735_TOPRGU_CONN_RST		9
#define MT6735_TOPRGU_C2K_SW_RST	14
#define MT6735_TOPRGU_C2K_RST		15
#define MT6735_TOPRGU_RST_NUM		9

#endif
