/* SPDX-License-Identifier: (GPL-2.0-only OR BSD-2-Clause) */

#ifndef _DT_BINDINGS_CLK_MT6735_IMGSYS_H
#define _DT_BINDINGS_CLK_MT6735_IMGSYS_H

#define CLK_IMG_SMI_LARB2		0
#define CLK_IMG_CAM_SMI			1
#define CLK_IMG_CAM_CAM			2
#define CLK_IMG_SEN_TG			3
#define CLK_IMG_SEN_CAM			4
#define CLK_IMG_CAM_SV			5
#define CLK_IMG_SUFOD			6
#define CLK_IMG_FD			7

#endif /* _DT_BINDINGS_CLK_MT6735_IMGSYS_H */
